@@ -310,7 +310,7 @@ def build_main(argv=sys.argv[1:]):  # type: ignore
 
 def main(argv=sys.argv[1:]):  # type: ignore
     # type: (List[unicode]) -> int
-    locale.setlocale(locale.LC_ALL, '')
+    sphinx.locale.setlocale(locale.LC_ALL, '')
     sphinx.locale.init_console(os.path.join(package_dir, 'locale'), 'sphinx')
 
     if argv[:1] == ['-M']:
