@@ -168,7 +168,7 @@ class Config(object):
             # old style arguments: (dirname, filename, overrides, tags)
             warnings.warn('The argument of Config() class has been changed. '
                           'Use Config.read() to read configuration from conf.py.',
-                          RemovedInSphinx30Warning)
+                          RemovedInSphinx30Warning, stacklevel=2)
             dirname, filename, overrides, tags = args
             if dirname is None:
                 config = {}  # type: Dict[unicode, Any]
@@ -206,13 +206,13 @@ class Config(object):
     def check_types(self):
         # type: () -> None
         warnings.warn('Config.check_types() is deprecated. Use check_confval_types() instead.',
-                      RemovedInSphinx30Warning)
+                      RemovedInSphinx30Warning, stacklevel=2)
         check_confval_types(None, self)
 
     def check_unicode(self):
         # type: () -> None
         warnings.warn('Config.check_unicode() is deprecated. Use check_unicode() instead.',
-                      RemovedInSphinx30Warning)
+                      RemovedInSphinx30Warning, stacklevel=2)
         check_unicode(self)
 
     def convert_overrides(self, name, value):
@@ -432,7 +432,7 @@ def correct_copyright_year(app, config):
         for k in ('copyright', 'epub_copyright'):
             if k in config:
                 replace = r'\g<1>%s' % format_date('%Y')
-                config[k] = copyright_year_re.sub(replace, config[k])  # type: ignore
+                config[k] = copyright_year_re.sub(replace, config[k])
 
 
 def check_confval_types(app, config):
