@@ -16,7 +16,7 @@ import warnings
 from collections import namedtuple
 from types import FunctionType, MethodType, ModuleType
 
-from six import PY2
+from six import PY2, iteritems
 
 from sphinx.util import logging
 from sphinx.util.inspect import isenumclass, safe_getattr
@@ -102,6 +102,7 @@ class _MockImporter(object):
         sys.meta_path.insert(0, self)
 
     def disable(self):
+        # type: () -> None
         # remove `self` from `sys.meta_path` to disable import hook
         sys.meta_path = [i for i in sys.meta_path if i is not self]
         # remove mocked modules from sys.modules to avoid side effects after
@@ -142,6 +143,7 @@ def mock(names):
 
 
 def import_module(modname, warningiserror=False):
+    # type: (str, bool) -> Any
     """
     Call __import__(modname), convert exceptions to ImportError
     """
@@ -165,8 +167,23 @@ def import_object(modname, objpath, objtype='', attrgetter=safe_getattr, warning
         logger.debug('[autodoc] import %s', modname)
 
     try:
-        module = import_module(modname, warningiserror=warningiserror)
-        logger.debug('[autodoc] => %r', module)
+        module = None
+        exc_on_importing = None
+        objpath = list(objpath)
+        while module is None:
+            try:
+                module = import_module(modname, warningiserror=warningiserror)
+                logger.debug('[autodoc] import %s => %r', modname, module)
+            except ImportError as exc:
+                logger.debug('[autodoc] import %s => failed', modname)
+                exc_on_importing = exc
+                if '.' in modname:
+                    # retry with parent module
+                    modname, name = modname.rsplit('.', 1)
+                    objpath.insert(0, name)
+                else:
+                    raise
+
         obj = module
         parent = None
         object_name = None
@@ -178,6 +195,10 @@ def import_object(modname, objpath, objtype='', attrgetter=safe_getattr, warning
             object_name = attrname
         return [module, parent, object_name, obj]
     except (AttributeError, ImportError) as exc:
+        if isinstance(exc, AttributeError) and exc_on_importing:
+            # restore ImportError
+            exc = exc_on_importing
+
         if objpath:
             errmsg = ('autodoc: failed to import %s %r from module %r' %
                       (objtype, '.'.join(objpath), modname))
@@ -227,6 +248,11 @@ def get_object_members(subject, objpath, attrgetter, analyzer=None):
             if name not in members:
                 members[name] = Attribute(name, True, value)
 
+        superclass = subject.__mro__[1]
+        for name, value in iteritems(obj_dict):
+            if name not in superclass.__dict__:
+                members[name] = Attribute(name, True, value)
+
     # other members
     for name in dir(subject):
         try:
