@@ -207,7 +207,7 @@ def copy_static_entry(source, targetdir, builder, context={},
     Handles all possible cases of files, directories and subdirectories.
     """
     warnings.warn('sphinx.util.copy_static_entry is deprecated for removal',
-                  RemovedInSphinx30Warning)
+                  RemovedInSphinx30Warning, stacklevel=2)
 
     if exclude_matchers:
         relpath = relative_path(path.join(builder.srcdir, 'dummy'), source)
@@ -301,7 +301,9 @@ def get_module_source(modname):
             raise PycodeError('error getting filename for %r' % filename, err)
     if filename is None and loader:
         try:
-            return 'string', loader.get_source(modname)
+            filename = loader.get_source(modname)
+            if filename:
+                return 'string', filename
         except Exception as err:
             raise PycodeError('error getting source for %r' % modname, err)
     if filename is None:
@@ -378,7 +380,7 @@ def detect_encoding(readline):
         except UnicodeDecodeError:
             return None
 
-        matches = _coding_re.findall(line_string)  # type: ignore
+        matches = _coding_re.findall(line_string)
         if not matches:
             return None
         return get_normal_name(matches[0])
@@ -596,12 +598,11 @@ def import_object(objname, source=None):
 
 def encode_uri(uri):
     # type: (unicode) -> unicode
-    split = list(urlsplit(uri))  # type: Any
+    split = list(urlsplit(uri))  # type: List[unicode]
     split[1] = split[1].encode('idna').decode('ascii')
-    split[2] = quote_plus(split[2].encode('utf-8'), '/').decode('ascii')
-    query = list((q, quote_plus(v.encode('utf-8')))
-                 for (q, v) in parse_qsl(split[3]))
-    split[3] = urlencode(query).decode('ascii')
+    split[2] = quote_plus(split[2].encode('utf-8'), '/')
+    query = list((q, v.encode('utf-8')) for (q, v) in parse_qsl(split[3]))
+    split[3] = urlencode(query)
     return urlunsplit(split)
 
 
