@@ -6,16 +6,26 @@
     Implements the low-level algorithms Sphinx uses for the versioning of
     doctrees.
 
-    :copyright: Copyright 2007-2017 by the Sphinx team, see AUTHORS.
+    :copyright: Copyright 2007-2018 by the Sphinx team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
-from uuid import uuid4
-from operator import itemgetter
+import warnings
 from itertools import product
+from operator import itemgetter
+from uuid import uuid4
 
 from six import iteritems
+from six.moves import cPickle as pickle
 from six.moves import range, zip_longest
 
+from sphinx.deprecation import RemovedInSphinx30Warning
+from sphinx.transforms import SphinxTransform
+
+if False:
+    # For type annotation
+    from typing import Any, Iterator  # NOQA
+    from docutils import nodes  # NOQA
+
 try:
     import Levenshtein
     IS_SPEEDUP = True
@@ -27,6 +37,7 @@ VERSIONING_RATIO = 65
 
 
 def add_uids(doctree, condition):
+    # type: (nodes.Node, Any) -> Iterator[nodes.Node]
     """Add a unique id to every node in the `doctree` which matches the
     condition and yield the nodes.
 
@@ -42,6 +53,7 @@ def add_uids(doctree, condition):
 
 
 def merge_doctrees(old, new, condition):
+    # type: (nodes.Node, nodes.Node, Any) -> Iterator[nodes.Node]
     """Merge the `old` doctree with the `new` one while looking at nodes
     matching the `condition`.
 
@@ -90,7 +102,7 @@ def merge_doctrees(old, new, condition):
     # choose the old node with the best ratio for each new node and set the uid
     # as long as the ratio is under a certain value, in which case we consider
     # them not changed but different
-    ratios = sorted(iteritems(ratios), key=itemgetter(1))
+    ratios = sorted(iteritems(ratios), key=itemgetter(1))  # type: ignore
     for (old_node, new_node), ratio in ratios:
         if new_node in seen:
             continue
@@ -109,6 +121,7 @@ def merge_doctrees(old, new, condition):
 
 
 def get_ratio(old, new):
+    # type: (unicode, unicode) -> float
     """Return a "similiarity ratio" (in percent) representing the similarity
     between the two strings where 0 is equal and anything above less than equal.
     """
@@ -122,6 +135,7 @@ def get_ratio(old, new):
 
 
 def levenshtein_distance(a, b):
+    # type: (unicode, unicode) -> int
     """Return the Levenshtein edit distance between two strings *a* and *b*."""
     if a == b:
         return 0
@@ -137,5 +151,41 @@ def levenshtein_distance(a, b):
             deletions = current_row[j] + 1
             substitutions = previous_row[j] + (column1 != column2)
             current_row.append(min(insertions, deletions, substitutions))
-        previous_row = current_row
+        previous_row = current_row  # type: ignore
     return previous_row[-1]
+
+
+class UIDTransform(SphinxTransform):
+    """Add UIDs to doctree for versioning."""
+    default_priority = 880
+
+    def apply(self):
+        # type: () -> None
+        env = self.env
+        old_doctree = None
+        if not env.versioning_condition:
+            return
+
+        if env.versioning_compare:
+            # get old doctree
+            try:
+                filename = env.doc2path(env.docname, env.doctreedir, '.doctree')
+                with open(filename, 'rb') as f:
+                    old_doctree = pickle.load(f)
+            except EnvironmentError:
+                pass
+
+        # add uids for versioning
+        if not env.versioning_compare or old_doctree is None:
+            list(add_uids(self.document, env.versioning_condition))
+        else:
+            list(merge_doctrees(old_doctree, self.document, env.versioning_condition))
+
+
+def prepare(document):
+    # type: (nodes.Node) -> None
+    """Simple wrapper for UIDTransform."""
+    warnings.warn('versioning.prepare() is deprecated. Use UIDTransform instead.',
+                  RemovedInSphinx30Warning, stacklevel=2)
+    transform = UIDTransform(document)
+    transform.apply()
